@@ -31,7 +31,7 @@ from .. import (
 )
 from .. import transport as _mod_transport
 from ..bzr import branch as bzrbranch
-from ..bzr import bzrdir, groupcompress_repo, vf_repository
+from ..bzr import bzrdir, groupcompress_repo
 from ..bzr.pack_repo import PackCommitBuilder
 
 # This is the dummy foreign revision control system, used
@@ -79,10 +79,10 @@ class DummyForeignVcs(foreign.ForeignVcs):
         self.abbreviation = "dummy"
 
     def show_foreign_revid(self, foreign_revid):
-        return {"dummy ding": "%s/%s\\%s" % foreign_revid}
+        return {"dummy ding": "{}/{}\\{}".format(*foreign_revid)}
 
     def serialize_foreign_revid(self, foreign_revid):
-        return "%s|%s|%s" % foreign_revid
+        return "{}|{}|{}".format(*foreign_revid)
 
 
 class DummyForeignVcsBranch(bzrbranch.BzrBranch6, foreign.ForeignBranch):
