@@ -144,7 +144,7 @@ class FakeNFSServer(DecoratorServer):
 
 
 class FakeVFATServer(DecoratorServer):
-    """A server that suggests connections through FakeVFATTransportDecorator
+    """A server that suggests connections through FakeVFATTransportDecorator.
 
     For use in testing.
     """
@@ -203,7 +203,8 @@ class UnlistableServer(DecoratorServer):
 class TestingPathFilteringServer(pathfilter.PathFilteringServer):
     def __init__(self):
         """TestingPathFilteringServer is not usable until start_server
-        is called."""
+        is called.
+        """
 
     def start_server(self, backing_server=None):
         """Setup the Chroot on backing_server."""
@@ -358,9 +359,7 @@ class TestingTCPServerMixin:
                 errno.ENOTCONN,
                 errno.EPIPE,
             ]
-        if isinstance(e, socket.error) and e.errno in accepted_errnos:
-            return True
-        return False
+        return bool(isinstance(e, socket.error) and e.errno in accepted_errnos)
 
     # The following methods are called by the main thread
 
@@ -480,18 +479,18 @@ class TestingThreadingTCPServer(TestingTCPServerMixin, socketserver.ThreadingTCP
             # re-raised
             if debug_threads():
                 sys.stderr.write(
-                    "Client thread %s will be joined\n" % (connection_thread.name,)
+                    "Client thread {} will be joined\n".format(connection_thread.name)
                 )
             connection_thread.join()
 
     def set_ignored_exceptions(self, thread, ignored_exceptions):
         TestingTCPServerMixin.set_ignored_exceptions(self, thread, ignored_exceptions)
-        for sock, addr, connection_thread in self.clients:
+        for _sock, _addr, connection_thread in self.clients:
             if connection_thread is not None:
                 connection_thread.set_ignored_exceptions(self.ignored_exceptions)
 
     def _pending_exception(self, thread):
-        for sock, addr, connection_thread in self.clients:
+        for _sock, _addr, connection_thread in self.clients:
             if connection_thread is not None:
                 connection_thread.pending_exception()
         TestingTCPServerMixin._pending_exception(self, thread)
@@ -525,7 +524,9 @@ class TestingTCPServerInAThread(transport.Server):
         self.host, self.port = self.server.server_address
         self._server_thread.name = self.server.server_address
         if debug_threads():
-            sys.stderr.write("Server thread %s started\n" % (self._server_thread.name,))
+            sys.stderr.write(
+                "Server thread {} started\n".format(self._server_thread.name)
+            )
         # If an exception occured during the server start, it will get raised,
         # otherwise, the server is blocked on its accept() call.
         self._server_thread.pending_exception()
@@ -547,7 +548,7 @@ class TestingTCPServerInAThread(transport.Server):
             self.server.serving = False
             if debug_threads():
                 sys.stderr.write(
-                    "Server thread %s will be joined\n" % (self._server_thread.name,)
+                    "Server thread {} will be joined\n".format(self._server_thread.name)
                 )
             # The server is listening for a last connection, let's give it:
             last_conn = None
@@ -639,7 +640,7 @@ class TestingSmartServer(TestingThreadingTCPServer, server.SmartTCPServer):
             self.run_server_stopped_hooks()
 
     def get_url(self):
-        """Return the url of the server"""
+        """Return the url of the server."""
         return "bzr://%s:%d/" % self.server_address
 
 
@@ -710,7 +711,7 @@ class SmartTCPServer_for_testing(TestingTCPServerInAThread):
         return url[:-1] + self.client_path_extra
 
     def get_bogus_url(self):
-        """Return a URL which will fail to connect"""
+        """Return a URL which will fail to connect."""
         return "bzr://127.0.0.1:1/"
 
 
