@@ -25,13 +25,12 @@ import socket
 import subprocess
 import sys
 from binascii import hexlify
-from typing import Dict, Optional, Set, Tuple, Type
 
 from .. import bedding, config, errors, osutils, trace, ui
 
 try:
     import paramiko
-except ModuleNotFoundError as e:
+except ModuleNotFoundError:
     # If we have an ssh subprocess, we don't strictly need paramiko for all ssh
     # access
     paramiko = None  # type: ignore
@@ -43,8 +42,8 @@ class StrangeHostname(errors.BzrError):
     _fmt = "Refusing to connect to strange SSH hostname %(hostname)s"
 
 
-SYSTEM_HOSTKEYS: Dict[str, Dict[str, str]] = {}
-BRZ_HOSTKEYS: Dict[str, Dict[str, str]] = {}
+SYSTEM_HOSTKEYS: dict[str, dict[str, str]] = {}
+BRZ_HOSTKEYS: dict[str, dict[str, str]] = {}
 
 
 class SSHVendorManager:
@@ -133,7 +132,7 @@ class SSHVendorManager:
         return self._get_vendor_by_version_string(version, "ssh")
 
     def _get_vendor_from_path(self, path):
-        """Return the vendor or None using the program at the given path"""
+        """Return the vendor or None using the program at the given path."""
         version = self._get_ssh_version_string([path, "-V"])
         return self._get_vendor_by_version_string(
             version, os.path.splitext(os.path.basename(path))[0]
@@ -297,7 +296,7 @@ class ParamikoVendor(SSHVendor):
             our_server_key_hex = self._hexify(our_server_key.get_fingerprint())
         else:
             trace.warning(
-                "Adding %s host key for %s: %s" % (keytype, host, server_key_hex)
+                "Adding {} host key for {}: {}".format(keytype, host, server_key_hex)
             )
             add = getattr(BRZ_HOSTKEYS, "add", None)
             if add is not None:  # paramiko >= 1.X.X
@@ -311,8 +310,9 @@ class ParamikoVendor(SSHVendor):
             filename1 = os.path.expanduser("~/.ssh/known_hosts")
             filename2 = _ssh_host_keys_config_dir()
             raise errors.TransportError(
-                "Host keys for %s do not match!  %s != %s"
-                % (host, our_server_key_hex, server_key_hex),
+                "Host keys for {} do not match!  {} != {}".format(
+                    host, our_server_key_hex, server_key_hex
+                ),
                 ["Try editing {} or {}".format(filename1, filename2)],
             )
 
@@ -341,7 +341,7 @@ class ParamikoVendor(SSHVendor):
             )
 
 
-_ssh_connection_errors: Tuple[Type[Exception], ...] = (
+_ssh_connection_errors: tuple[type[Exception], ...] = (
     EOFError,
     OSError,
     IOError,
@@ -477,7 +477,7 @@ register_ssh_vendor("sshcorp", SSHCorpSubprocessVendor())
 
 
 class LSHSubprocessVendor(SubprocessVendor):
-    """SSH vendor that uses the 'lsh' executable from GNU"""
+    """SSH vendor that uses the 'lsh' executable from GNU."""
 
     executable_path = "lsh"
 
@@ -532,11 +532,13 @@ def _paramiko_auth(username, password, host, port, paramiko_transport):
         username = auth.get_user("ssh", host, port=port, default=getpass.getuser())
     agent = paramiko.Agent()
     for key in agent.get_keys():
-        trace.mutter("Trying SSH agent key %s" % hexlify(key.get_fingerprint()).upper())
+        trace.mutter(
+            "Trying SSH agent key {}".format(hexlify(key.get_fingerprint()).upper())
+        )
         try:
             paramiko_transport.auth_publickey(username, key)
             return
-        except paramiko.SSHException as e:
+        except paramiko.SSHException:
             pass
 
     # okay, try finding id_rsa or id_dss?  (posix only)
@@ -561,7 +563,7 @@ def _paramiko_auth(username, password, host, port, paramiko_transport):
     except paramiko.BadAuthenticationType as e:
         # Supported methods are in the exception
         supported_auth_types = e.allowed_types
-    except paramiko.SSHException as e:
+    except paramiko.SSHException:
         # Don't know what happened, but just ignore it
         pass
     # We treat 'keyboard-interactive' and 'password' auth methods identically,
@@ -578,15 +580,16 @@ def _paramiko_auth(username, password, host, port, paramiko_transport):
     ):
         raise errors.ConnectionError(
             "Unable to authenticate to SSH host as"
-            "\n  %s@%s\nsupported auth types: %s"
-            % (username, host, supported_auth_types)
+            "\n  {}@{}\nsupported auth types: {}".format(
+                username, host, supported_auth_types
+            )
         )
 
     if password:
         try:
             paramiko_transport.auth_password(username, password)
             return
-        except paramiko.SSHException as e:
+        except paramiko.SSHException:
             pass
 
     # give up and ask for a password
@@ -597,13 +600,14 @@ def _paramiko_auth(username, password, host, port, paramiko_transport):
             paramiko_transport.auth_password(username, password)
         except paramiko.SSHException as e:
             raise errors.ConnectionError(
-                "Unable to authenticate to SSH host as"
-                "\n  %s@%s\n" % (username, host),
+                "Unable to authenticate to SSH host as\n  {}@{}\n".format(
+                    username, host
+                ),
                 e,
             )
     else:
         raise errors.ConnectionError(
-            "Unable to authenticate to SSH host as" "  %s@%s" % (username, host)
+            "Unable to authenticate to SSH host as  {}@{}".format(username, host)
         )
 
 
@@ -623,11 +627,13 @@ def _try_pkey_auth(paramiko_transport, pkey_class, username, filename):
             return True
         except paramiko.SSHException:
             trace.mutter(
-                "SSH authentication via %s key failed." % (os.path.basename(filename),)
+                "SSH authentication via {} key failed.".format(
+                    os.path.basename(filename)
+                )
             )
     except paramiko.SSHException:
         trace.mutter(
-            "SSH authentication via %s key failed." % (os.path.basename(filename),)
+            "SSH authentication via {} key failed.".format(os.path.basename(filename))
         )
     except OSError:
         pass
@@ -639,8 +645,7 @@ def _ssh_host_keys_config_dir():
 
 
 def load_host_keys():
-    """
-    Load system host keys (probably doesn't work on windows) and any
+    """Load system host keys (probably doesn't work on windows) and any
     "discovered" keys from previous sessions.
     """
     global SYSTEM_HOSTKEYS, BRZ_HOSTKEYS
@@ -659,9 +664,7 @@ def load_host_keys():
 
 
 def save_host_keys():
-    """
-    Save "discovered" host keys in $(config)/ssh_host_keys/.
-    """
+    """Save "discovered" host keys in $(config)/ssh_host_keys/."""
     global SYSTEM_HOSTKEYS, BRZ_HOSTKEYS
     bzr_hostkey_path = _ssh_host_keys_config_dir()
     bedding.ensure_config_dir_exists()
@@ -671,7 +674,7 @@ def save_host_keys():
             f.write("# SSH host keys collected by bzr\n")
             for hostname, keys in BRZ_HOSTKEYS.items():
                 for keytype, key in keys.items():
-                    f.write("%s %s %s\n" % (hostname, keytype, key.get_base64()))
+                    f.write("{} {} {}\n".format(hostname, keytype, key.get_base64()))
     except OSError as e:
         trace.mutter("failed to save bzr host keys: " + str(e))
 
@@ -705,7 +708,7 @@ def os_specific_subprocess_params():
 
 import weakref
 
-_subproc_weakrefs: Set[weakref.ref] = set()
+_subproc_weakrefs: set[weakref.ref] = set()
 
 
 def _close_ssh_proc(proc, sock):
