@@ -25,9 +25,8 @@ import stat
 import sys
 from io import BytesIO
 
-from .. import errors, osutils, pyutils, tests
+from .. import errors, osutils, pyutils, urlutils
 from .. import transport as _mod_transport
-from .. import urlutils
 from ..errors import ConnectionError, PathError, TransportNotPossible
 from ..osutils import getcwd
 from ..transport import (
@@ -47,8 +46,9 @@ def get_transport_test_permutations(module):
     """Get the permutations module wants to have tested."""
     if getattr(module, "get_test_permutations", None) is None:
         raise AssertionError(
-            "transport module %s doesn't provide get_test_permutations()"
-            % module.__name__
+            "transport module {} doesn't provide get_test_permutations()".format(
+                module.__name__
+            )
         )
         return []
     return module.get_test_permutations()
@@ -68,7 +68,7 @@ def transport_test_permutations():
                     {"transport_class": klass, "transport_server": server_factory},
                 )
                 result.append(scenario)
-        except errors.DependencyNotPresent as e:
+        except errors.DependencyNotPresent:
             # Continue even if a dependency prevents us
             # from adding this test
             pass
@@ -92,7 +92,7 @@ class TransportTests(TestTransportImplementation):
         self.assertEqualDiff(content, transport.get_bytes(relpath))
 
     def test_ensure_base_missing(self):
-        """.ensure_base() should create the directory if it doesn't exist"""
+        """.ensure_base() should create the directory if it doesn't exist."""
         t = self.get_transport()
         t_a = t.clone("a")
         self.assertFalse(t.ensure_base())
@@ -103,7 +103,7 @@ class TransportTests(TestTransportImplementation):
         self.assertTrue(t.has("a"))
 
     def test_ensure_base_exists(self):
-        """.ensure_base() should just be happy if it already exists"""
+        """.ensure_base() should just be happy if it already exists."""
         t = self.get_transport()
         if t.is_readonly():
             return
@@ -114,7 +114,7 @@ class TransportTests(TestTransportImplementation):
         self.assertFalse(t_a.ensure_base())
 
     def test_ensure_base_missing_parent(self):
-        """.ensure_base() will fail if the parent dir doesn't exist"""
+        """.ensure_base() will fail if the parent dir doesn't exist."""
         t = self.get_transport()
         if t.is_readonly():
             return
@@ -147,8 +147,7 @@ class TransportTests(TestTransportImplementation):
     def test_has_root_works(self):
         if self.transport_server is test_server.SmartTCPServer_for_testing:
             raise TestNotApplicable(
-                "SmartTCPServer_for_testing intentionally does not allow "
-                "access to /."
+                "SmartTCPServer_for_testing intentionally does not allow access to /."
             )
         current_transport = self.get_transport()
         self.assertTrue(current_transport.has("/"))
@@ -158,7 +157,6 @@ class TransportTests(TestTransportImplementation):
     def test_get(self):
         t = self.get_transport()
 
-        files = ["a"]
         content = b"contents of a\n"
         self.build_tree(["a"], transport=t, line_endings="binary")
         self.check_transport_contents(b"contents of a\n", t, "a")
@@ -168,10 +166,6 @@ class TransportTests(TestTransportImplementation):
     def test_get_unknown_file(self):
         t = self.get_transport()
         files = ["a", "b"]
-        contents = [
-            b"contents of a\n",
-            b"contents of b\n",
-        ]
         self.build_tree(files, transport=t, line_endings="binary")
         self.assertRaises(NoSuchFile, t.get, "c")
 
@@ -180,11 +174,11 @@ class TransportTests(TestTransportImplementation):
                 # We call f.read() here because things like paramiko actually
                 # spawn a thread to prefetch the content, which we want to
                 # consume before we close the handle.
-                content = f.read()
+                f.read()
                 f.close()
 
     def test_get_directory_read_gives_ReadError(self):
-        """consistent errors for read() on a file returned by get()."""
+        """Consistent errors for read() on a file returned by get()."""
         t = self.get_transport()
         if t.is_readonly():
             self.build_tree(["a directory/"])
@@ -718,7 +712,7 @@ class TransportTests(TestTransportImplementation):
         self.assertRaises(NoSuchFile, t.append_bytes, "missing/path", b"content")
 
     def test_append_file_mode(self):
-        """Check that append accepts a mode parameter"""
+        """Check that append accepts a mode parameter."""
         # check append accepts a mode
         t = self.get_transport()
         if t.is_readonly():
@@ -795,7 +789,7 @@ class TransportTests(TestTransportImplementation):
         self.assertRaises((NoSuchFile, PathError), t.rmdir, "adir")
 
     def test_rmdir_not_empty(self):
-        """Deleting a non-empty directory raises an exception
+        """Deleting a non-empty directory raises an exception.
 
         sftp (and possibly others) don't give us a specific "directory not
         empty" exception -- we can just see that the operation failed.
@@ -808,7 +802,7 @@ class TransportTests(TestTransportImplementation):
         self.assertRaises(PathError, t.rmdir, "adir")
 
     def test_rmdir_empty_but_similar_prefix(self):
-        """rmdir does not get confused by sibling paths.
+        """Rmdir does not get confused by sibling paths.
 
         A naive implementation of MemoryTransport would refuse to rmdir
         ".bzr/branch" if there is a ".bzr/branch-format" directory, because it
@@ -839,7 +833,7 @@ class TransportTests(TestTransportImplementation):
         self.assertFalse(t.has("adir"))
 
     def test_rename_dir_nonempty(self):
-        """Attempting to replace a nonemtpy directory should fail"""
+        """Attempting to replace a nonemtpy directory should fail."""
         t = self.get_transport()
         if t.is_readonly():
             self.assertRaises(
@@ -965,7 +959,7 @@ class TransportTests(TestTransportImplementation):
             url = self._server.get_bogus_url()
         except NotImplementedError:
             raise TestSkipped(
-                "Transport %s has no bogus URL support." % self._server.__class__
+                "Transport {} has no bogus URL support.".format(self._server.__class__)
             )
         t = _mod_transport.get_transport_from_url(url)
         self.assertRaises((ConnectionError, NoSuchFile), t.get, ".bzr/branch")
@@ -978,7 +972,7 @@ class TransportTests(TestTransportImplementation):
 
         try:
             st = t.stat(".")
-        except TransportNotPossible as e:
+        except TransportNotPossible:
             # This transport cannot stat
             return
 
@@ -1023,7 +1017,9 @@ class TransportTests(TestTransportImplementation):
             self.assertEqual(st[ST_NLINK], 2)
         except TransportNotPossible:
             raise TestSkipped(
-                "Transport %s does not support hardlinks." % self._server.__class__
+                "Transport {} does not support hardlinks.".format(
+                    self._server.__class__
+                )
             )
 
     def test_symlink(self):
@@ -1044,11 +1040,12 @@ class TransportTests(TestTransportImplementation):
 
             st = t.stat(link_name)
             self.assertTrue(
-                S_ISLNK(st.st_mode), "expected symlink, got mode %o" % st.st_mode
+                S_ISLNK(st.st_mode),
+                "expected symlink, got mode {:o}".format(st.st_mode),
             )
         except TransportNotPossible:
             raise TestSkipped(
-                "Transport %s does not support symlinks." % self._server.__class__
+                "Transport {} does not support symlinks.".format(self._server.__class__)
             )
 
         self.assertEqual(source_name, t.readlink(link_name))
@@ -1059,7 +1056,7 @@ class TransportTests(TestTransportImplementation):
             self.assertRaises(NoSuchFile, t.readlink, "nonexistent")
         except TransportNotPossible:
             raise TestSkipped(
-                "Transport %s does not support symlinks." % self._server.__class__
+                "Transport {} does not support symlinks.".format(self._server.__class__)
             )
 
     def test_list_dir(self):
@@ -1364,7 +1361,7 @@ class TransportTests(TestTransportImplementation):
             p = transport.local_abspath(".")
         except (errors.NotLocalUrl, TransportNotPossible) as e:
             # should be formattable
-            s = str(e)
+            str(e)
         else:
             self.assertEqual(getcwd(), p)
 
@@ -1775,13 +1772,15 @@ class TransportTests(TestTransportImplementation):
 
     def test_no_segment_parameters(self):
         """Segment parameters should be stripped and stored in
-        transport.segment_parameters."""
+        transport.segment_parameters.
+        """
         transport = self.get_transport("foo")
         self.assertEqual({}, transport.get_segment_parameters())
 
     def test_segment_parameters(self):
         """Segment parameters should be stripped and stored in
-        transport.get_segment_parameters()."""
+        transport.get_segment_parameters().
+        """
         base_url = self._server.get_url()
         parameters = {"key1": "val1", "key2": "val2"}
         url = urlutils.join_segment_parameters(base_url, parameters)
@@ -1793,7 +1792,7 @@ class TransportTests(TestTransportImplementation):
         transport = self.get_transport("foo")
         orig_base = transport.base
         transport.set_segment_parameter("arm", "board")
-        self.assertEqual("%s,arm=board" % orig_base, transport.base)
+        self.assertEqual("{},arm=board".format(orig_base), transport.base)
         self.assertEqual({"arm": "board"}, transport.get_segment_parameters())
         transport.set_segment_parameter("arm", None)
         transport.set_segment_parameter("nonexistant", None)
@@ -1813,7 +1812,7 @@ class TransportTests(TestTransportImplementation):
         self.assertTrue(stat.S_ISLNK(st.st_mode))
 
     def test_abspath_url_unquote_unreserved(self):
-        """URLs from abspath should have unreserved characters unquoted
+        """URLs from abspath should have unreserved characters unquoted.
 
         Need consistent quoting notably for tildes, see lp:842223 for more.
         """
@@ -1822,7 +1821,7 @@ class TransportTests(TestTransportImplementation):
         self.assertEqual(t.base + "-.09AZ_az~", t.abspath(needlessly_escaped_dir))
 
     def test_clone_url_unquote_unreserved(self):
-        """Base URL of a cloned branch needs unreserved characters unquoted
+        """Base URL of a cloned branch needs unreserved characters unquoted.
 
         Cloned transports should be prefix comparable for things like the
         isolation checking of tests, see lp:842223 for more.
@@ -1834,7 +1833,7 @@ class TransportTests(TestTransportImplementation):
         self.assertEqual(t1.base + "-.09AZ_az~/", t2.base)
 
     def test_hook_post_connection_one(self):
-        """Fire post_connect hook after a ConnectedTransport is first used"""
+        """Fire post_connect hook after a ConnectedTransport is first used."""
         log = []
         Transport.hooks.install_named_hook("post_connect", log.append, None)
         t = self.get_transport()
@@ -1848,7 +1847,7 @@ class TransportTests(TestTransportImplementation):
             self.assertEqual([], log)
 
     def test_hook_post_connection_multi(self):
-        """Fire post_connect hook once per unshared underlying connection"""
+        """Fire post_connect hook once per unshared underlying connection."""
         log = []
         Transport.hooks.install_named_hook("post_connect", log.append, None)
         t1 = self.get_transport()
